==> flow-server-24.9-20260302.033547-427-sources.jar: com/vaadin/flow/hotswap/impl/ErrorViewHotswapper.java <==
/*
 * Copyright 2000-2026 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.hotswap.impl;

import jakarta.annotation.Priority;

import com.vaadin.flow.component.UI;
import com.vaadin.flow.hotswap.VaadinHotswapper;
import com.vaadin.flow.server.VaadinSession;

import java.util.Set;

/**
 * Triggers UI refresh when hotswap occurs while an error view is displayed.
 * This ensures that fixing a broken class during development will refresh the
 * error page and attempt to re-navigate to the original location.
 * <p>
 * For internal use only. May be renamed or removed in a future release.
 *
 * @since 25.0
 */
@Priority(100)
public class ErrorViewHotswapper implements VaadinHotswapper {

    @Override
    public boolean onClassLoadEvent(VaadinSession session,
            Set<Class<?>> classes, boolean redefined) {
        // Only process redefined classes (not first-time loads)
        if (!redefined) {
            return false;
        }

        // Check each UI in the session
        for (UI ui : session.getUIs()) {
            if (ui.isClosing()) {
                continue;
            }

            // If showing error view, trigger page reload
            if (ui.getInternals().isShowingErrorView()) {
                return true;
            }
        }
        return false;
    }
}

==> flow-server-25.0.6-sources.jar: com/vaadin/flow/hotswap/impl/ErrorViewHotswapper.java <==
/*
 * Copyright 2000-2026 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.hotswap.impl;

import jakarta.annotation.Priority;

import com.vaadin.flow.component.UI;
import com.vaadin.flow.hotswap.HotswapClassSessionEvent;
import com.vaadin.flow.hotswap.UIUpdateStrategy;
import com.vaadin.flow.hotswap.VaadinHotswapper;
import com.vaadin.flow.server.VaadinSession;

/**
 * Triggers UI refresh when hotswap occurs while an error view is displayed.
 * This ensures that fixing a broken class during development will refresh the
 * error page and attempt to re-navigate to the original location.
 * <p>
 * For internal use only. May be renamed or removed in a future release.
 *
 * @since 25.0
 */
@Priority(100)
public class ErrorViewHotswapper implements VaadinHotswapper {

    @Override
    public void onClassesChange(HotswapClassSessionEvent event) {
        // Only process redefined classes (not first-time loads)
        if (!event.isRedefined()) {
            return;
        }

        VaadinSession session = event.getVaadinSession();

        // Check each UI in the session
        for (UI ui : session.getUIs()) {
            if (ui.isClosing()) {
                continue;
            }

            // If showing error view, trigger refresh to re-attempt navigation
            if (ui.getInternals().isShowingErrorView()) {
                event.triggerUpdate(ui, UIUpdateStrategy.REFRESH);
            }
        }
    }
}
